==> react-native-cometchat-calling-component-1.1.2.tgz: package/components/ButtonBar.js <==
import React, {Component} from 'react';
import { View } from 'react-native';
import AudioButton from './AudioButton';
import AudioModeButton from './AudioModeButton';
import VideoButton from './VideoButton';
import SwitchCameraButton from './SwitchCameraButton';
import HangUpButton from './HangUpButton';

class ButtonBar extends Component{
    constructor(props){
        super(props);
    }

    render(){
        var hideAudioModeButton = this.props.hideAudioModeButton || false ;
        var hideAudioMuteButton = this.props.hideAudioMuteButton || false ;
        var hidePauseVideoButton = this.props.hidePauseVideoButton || false ;
        var hideEndCallButton = this.props.hideEndCallButton || false ;
        var hideVideoSwitchButton = this.props.hideVideoSwitchButton || false ;
        

        return(
            <View>
                <View style={this.style.container_background}/>
                <View id="lt_control_container" style={ this.style.lt_control_container }>
                    { hideAudioMuteButton ? null : <AudioButton/> }
                    { hidePauseVideoButton ? null : <VideoButton /> }
                    { hideEndCallButton ? null : <HangUpButton /> }
                    { hideVideoSwitchButton ? null : <SwitchCameraButton /> }
                    { hideAudioModeButton ? null : <AudioModeButton /> }
                </View>
            </View>
        )
    }

    style = {
        lt_control_container: { 
            display:'flex', 
            width: '100%', 
            flexDirection: 'row', 
            justifyContent: 'center', 
            alignItems: 'center', 
            flexWrap: 'wrap', 
            position: 'absolute',
            bottom: 10,
            zIndex: 5 
        },
        container_background:{
            display:'flex', 
            width: '100%',
            height: 100, 
            flexDirection: 'row', 
            justifyContent: 'center', 
            alignItems: 'center', 
            flexWrap: 'wrap', 
            position: 'absolute', 
            bottom: 0,
            zIndex: 2,
            opacity:0.4,
            borderTopLeftRadius: 20,
            borderTopRightRadius: 20,
            backgroundColor: '#2e2f30'
        },
        container_main:{
            zIndex: 2
        }
    };
}
export default ButtonBar;

==> react-native-cometchat-calling-component-1.1.7.tgz: package/components/ButtonBar.js <==
import React, {Component} from 'react';
import { View } from 'react-native';
import AudioButton from './AudioButton';
import AudioModeButton from './AudioModeButton';
import VideoButton from './VideoButton';
import SwitchCameraButton from './SwitchCameraButton';
import HangUpButton from './HangUpButton';

class ButtonBar extends Component{
    constructor(props){
        super(props);
    }

    render(){
        var hideAudioModeButton = this.props.hideAudioModeButton || false ;
        var hideAudioMuteButton = this.props.hideAudioMuteButton || false ;
        var hidePauseVideoButton = this.props.hidePauseVideoButton || false ;
        var hideEndCallButton = this.props.hideEndCallButton || false ;
        var hideVideoSwitchButton = this.props.hideVideoSwitchButton || false ;
        

        return(
            <View style ={this.style.container}>
                <View style={this.style.container_background}
                />
                <View id="lt_control_container" style={ this.style.lt_control_container }>
                    { hideAudioMuteButton ? null : <AudioButton/> }
                    { hidePauseVideoButton ? null : <VideoButton /> }
                    { hideEndCallButton ? null : <HangUpButton /> }
                    { hideVideoSwitchButton ? null : <SwitchCameraButton /> }
                    { hideAudioModeButton ? null : <AudioModeButton /> }
                </View>
            </View>
        )
    }

    style = {
        lt_control_container: { 
            display:'flex', 
            width: '100%', 
            flexDirection: 'row', 
            justifyContent: 'center', 
            alignItems: 'center', 
            flexWrap: 'wrap', 
            position: 'absolute',
            bottom: 10,
            zIndex: 5 
        },
        container_background:{
            display:'flex', 
            width: '100%',
            height: 100, 
            flexDirection: 'row', 
            justifyContent: 'center', 
            alignItems: 'center', 
            flexWrap: 'wrap', 
            position: 'absolute', 
            bottom: 0,
            zIndex: 2,
            opacity:0.4,
            borderTopLeftRadius: 20,
            borderTopRightRadius: 20,
            backgroundColor: '#2e2f30'
        },
        container: Platform.OS === 'ios' ? { zIndex: 2 }  : { },
    };
}
export default ButtonBar;
